@@ -2,7 +2,7 @@ package Nephia;
 use strict;
 use warnings;
 use File::Spec;
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 sub import {
     my ($class, %opts) = @_;
@@ -22,6 +22,7 @@ sub import {
 
     for my $plugin ( map {"Nephia::Plugin::$_"} @plugins ) {
         require File::Spec->catfile(split/::/, $plugin.'.pm');
+        $plugin->import if *{$plugin."::import"}{CODE};
         for my $func (grep { $_ =~ /^[a-z]/ && $_ ne 'import' } keys %{$plugin.'::'}) {
             *{$caller.'::'.$func} = *{$plugin.'::'.$func};
         }
@@ -221,11 +222,18 @@ The only rule, namespace of new module must begins in "Nephia::Plugin::".
 
 If you want to export subroutines, those name must begin in lower alphabetic chars, and it must not be "import".
 
+import() will execute when plugin is loaded.
+
 For example.
 
   package Nephia::Plugin::Bark;
-  use Exporter 'import';
-  our @EXPORT = qw[ bark barkbark ];
+  use strict;
+  use warnings;
+
+  sub import {
+      my ($class) = @_;
+      ... ### Be execute when plugin is loaded.
+  }
   
   sub bark () {
       return [200, [], ['Bark!']];
